@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.16";
+        "11.0.16.1";
 
     private static final String java_version_date =
-        "2022-07-19";
+        "2022-08-12";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.16+8";
+        "11.0.16.1+1";
 
     private static final String VERSION_NUMBER =
-        "11.0.16";
+        "11.0.16.1";
 
     private static final String VERSION_BUILD =
-        "8";
+        "1";
 
     private static final String VERSION_PRE =
         "";
