@@ -3,9 +3,9 @@ package jdk.javadoc.internal.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.15+3" },
-            { "jdk", "11.0.15" },
-            { "release", "11.0.15" },
+            { "full", "11.0.16.1+1" },
+            { "jdk", "11.0.16.1" },
+            { "release", "11.0.16.1" },
         };
     }
 }
